@@ -11,7 +11,7 @@
 **  
 **  ======================================================================
 **
-**  Copyright (c) 1996-1999 Ralf S. Engelschall.
+**  Copyright (c) 1997-2004 Ralf S. Engelschall.
 **
 **  This program is free software; it may be redistributed and/or
 **  modified only under the terms of the GNU General Public License, 
@@ -36,7 +36,7 @@
 #include <signal.h>
 #include <string.h>
 #ifdef USE_NCURSES
-#include <ncurses.h>
+#include <ncurses/ncurses.h>
 #endif
 #ifdef USE_SLCURSES
 #include <slcurses.h>
