@@ -11,7 +11,7 @@
 **  
 **  ======================================================================
 **
-**  Copyright (c) 1996-1999 Ralf S. Engelschall.
+**  Copyright (c) 1997-2004 Ralf S. Engelschall.
 **
 **  This program is free software; it may be redistributed and/or
 **  modified only under the terms of the GNU General Public License, 
@@ -39,17 +39,18 @@
 #include "iselect_getopt.h"
 #include "iselect_browse.h"
 #include "iselect_keys.h"
-#define AS_HEADER
+
+#define _ISELECT_VERSION_C_AS_HEADER_
 #include "iselect_version.c"
+#undef  _ISELECT_VERSION_C_AS_HEADER_
 
 void give_version(char *name);
 void give_usage(char *name);
 
 void give_version(char *name)
 {
-    fprintf(stderr, "%s\n", iSelect_Hello);
-    fprintf(stdout, "\n");
-    fprintf(stdout, "Copyright (c) 1996,1997,1998 Ralf S. Engelschall.\n");
+    fprintf(stderr, "%s\n", iselect_version.v_tex);
+    fprintf(stdout, "Copyright (c) 1997-2000 Ralf S. Engelschall <rse@engelschall.com>\n");
     fprintf(stdout, "\n");
     fprintf(stdout, "This program is distributed in the hope that it will be useful,\n");
     fprintf(stdout, "but WITHOUT ANY WARRANTY; without even the implied warranty of\n");
